/*-----------------------------------------------------------------------------
 * Name:    Keyboard.c
 * Purpose: Low level Keyboard functions
 * Note(s): possible defines select the used communication interface:
 *            __USE_FPGA  - use Buttons connected through FPGA
 *                        - use Buttons connected through SCC (default)
 *-----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2013 KEIL - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "SMM_MPS2.h"                   // Keil::Board Support:V2M-MPS2:Common
#include "Keyboard.h"                   // Keil::Board Support:V2M-MPS2:Keyboard


#if defined __USE_FPGA
  #define KEY_PORT   MPS2_FPGAIO->BUTTON
  #define NUM_KEYS   2
#else
  #define KEY_PORT   MPS2_SCC->CFG_REG3
  #define NUM_KEYS   8
#endif

/*-----------------------------------------------------------------------------
  Initialize keyboard/buttons
 *----------------------------------------------------------------------------*/
void Keyboard_Initialize (void) {

}


/*-----------------------------------------------------------------------------
  Uninitialize keyboard/buttons
 *----------------------------------------------------------------------------*/
void Keyboard_Uninitialize (void) {
}


/*-----------------------------------------------------------------------------
 *      Keyboard_GetKeys:  Get keyboard state
 *
 * Parameters: (none)
 * Return:      Keys bitmask
 *----------------------------------------------------------------------------*/
uint32_t Keyboard_GetKeys (void) {
  uint32_t val = 0;

  val = KEY_PORT & ((1ul << NUM_KEYS) - 1);
  return (val);
}


/*-----------------------------------------------------------------------------
 *      Keyboard_NumKeys:  Get number of available keys
 *
 * Parameters: (none)
 * Return:      number of keys
 *----------------------------------------------------------------------------*/
uint32_t Keyboard_NumKeys (void) {
  return (NUM_KEYS);
}
