/*-----------------------------------------------------------------------------
 * Name:    LED.c
 * Purpose: Low level LED functions
 * Note(s): possible defines select the used communication interface:
 *            __USE_FPGA  - use LEDs connected through FPGA
 *                        - use LEDs connected through SCC (default)
 *-----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2013 KEIL - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "SMM_MPS2.h"                   // Keil::Board Support:V2M-MPS2:Common
#include "LED.h"                        // Keil::Board Support:V2M-MPS2:LED

#if defined __USE_FPGA
  #define LED_PORT   MPS2_FPGAIO->LED
  #define NUM_LEDS   2
#else
  #define LED_PORT   MPS2_SCC->CFG_REG1
  #define NUM_LEDS   8
#endif


/*----------------------------------------------------------------------------
  Initialize LED pins
 *----------------------------------------------------------------------------*/
void LED_Initialize (void) {
  uint32_t n;

  for (n = 0; n < NUM_LEDS; n++) {
    LED_Off (n);
  }

}


/*----------------------------------------------------------------------------
  Uninitialize LED pins
 *----------------------------------------------------------------------------*/
void LED_Uninitialize (void) {

}

/*-----------------------------------------------------------------------------
  Turns on requested LED
    num - LED number
 *----------------------------------------------------------------------------*/
void LED_On (uint32_t num) {

  if (num < NUM_LEDS) {
    LED_PORT |=  (1ul << num);
  }
}

/*-----------------------------------------------------------------------------
  Turns off requested LED
    num - LED number
 *----------------------------------------------------------------------------*/
void LED_Off (uint32_t num) {

 if (num < NUM_LEDS) {
    LED_PORT &= ~(1ul << num);
  }
}

/*-----------------------------------------------------------------------------
  Write value to LEDs
    val - value to be displayed on LEDs
 *----------------------------------------------------------------------------*/
void LED_Out (uint32_t val) {
//  uint32_t n;

//  for (n = 0; n < NUM_LEDS; n++) {
//    if (val & (1<<n)) {
//      LED_On (n);
//    } else {
//      LED_Off(n);
//    }
//  }
  LED_PORT = val & (NUM_LEDS - 1);
}

/*-----------------------------------------------------------------------------
  Get number of available LEDs
 *----------------------------------------------------------------------------*/
uint32_t LED_NumLeds (void) {
  return (NUM_LEDS);
}
